@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "fake.h"
 #include "parser.h"
@@ -93,7 +81,7 @@ void Fake::setConfig(const ConfigPtr &config)
 {
     qCDebug(KSCREEN_FAKE) << "set config" << config->outputs();
     mConfig = config->clone();
-    emit configChanged(mConfig);
+    Q_EMIT configChanged(mConfig);
 }
 
 bool Fake::isValid() const
@@ -111,7 +99,7 @@ QByteArray Fake::edid(int outputId) const
     const QJsonObject json = jsonDoc.object();
 
     const QJsonArray outputs = json[QStringLiteral("outputs")].toArray();
-    Q_FOREACH (const QJsonValue &value, outputs) {
+    for (const QJsonValue &value : outputs) {
         const QVariantMap output = value.toObject().toVariantMap();
         if (output[QStringLiteral("id")].toInt() != outputId) {
             continue;
@@ -152,7 +140,7 @@ void Fake::setPrimary(int outputId, bool primary)
         return;
     }
 
-    Q_FOREACH (KScreen::OutputPtr output, config()->outputs()) {
+    for (KScreen::OutputPtr output : config()->outputs()) {
         if (output->id() == outputId) {
             output->setPrimary(primary);
         } else {
