@@ -203,13 +203,13 @@ ConfigPtr Config::clone() const
 {
     ConfigPtr newConfig(new Config());
     newConfig->d->screen = d->screen->clone();
-    for (const OutputPtr &ourOutput : d->outputs) {
-        newConfig->addOutput(ourOutput->clone());
-    }
-    newConfig->d->primaryOutput = newConfig->d->findPrimaryOutput();
     newConfig->setSupportedFeatures(supportedFeatures());
     newConfig->setTabletModeAvailable(tabletModeAvailable());
     newConfig->setTabletModeEngaged(tabletModeEngaged());
+    for (const OutputPtr &ourOutput : qAsConst(d->outputs)) {
+        newConfig->addOutput(ourOutput->clone());
+    }
+    newConfig->d->primaryOutput = newConfig->d->findPrimaryOutput();
     return newConfig;
 }
 
@@ -325,6 +325,7 @@ void Config::setPrimaryOutput(const OutputPtr &newPrimary)
 void Config::addOutput(const OutputPtr &output)
 {
     d->outputs.insert(output->id(), output);
+    output->setExplicitLogicalSize(logicalSizeForOutput(*output));
     connect(output.data(), &KScreen::Output::isPrimaryChanged, d, &KScreen::Config::Private::onPrimaryOutputChanged);
 
     Q_EMIT outputAdded(output);
@@ -365,6 +366,9 @@ void Config::apply(const ConfigPtr &other)
 {
     d->screen->apply(other->screen());
 
+    setTabletModeAvailable(other->tabletModeAvailable());
+    setTabletModeEngaged(other->tabletModeEngaged());
+
     // Remove removed outputs
     for (auto it = d->outputs.begin(); it != d->outputs.end();) {
         if (!other->d->outputs.contains((*it)->id())) {
@@ -381,6 +385,7 @@ void Config::apply(const ConfigPtr &other)
         } else {
             // Update existing outputs
             d->outputs[otherOutput->id()]->apply(otherOutput);
+            d->outputs[otherOutput->id()]->setExplicitLogicalSize(logicalSizeForOutput(*d->outputs[otherOutput->id()]));
         }
     }
 
@@ -388,6 +393,37 @@ void Config::apply(const ConfigPtr &other)
     setValid(other->isValid());
 }
 
+QRect Config::outputGeometryForOutput(const KScreen::Output &output) const
+{
+    QSize size = logicalSizeForOutput(output).toSize();
+    if (!size.isValid()) {
+        return QRect();
+    }
+
+    return QRect(output.pos(), size);
+}
+
+QSizeF Config::logicalSizeForOutput(const KScreen::Output &output) const
+{
+    QSizeF size = output.enforcedModeSize();
+    if (!size.isValid()) {
+        return QSizeF();
+    }
+    // ignore scale where scaling is not per-output
+    if (supportedFeatures().testFlag(Feature::PerOutputScaling)) {
+        size = size / output.scale();
+    }
+
+    // We can't use output.size(), because it does not reflect the actual rotation() set by caller.
+    // It is only updated when we get update from KScreen, but not when user changes mode or
+    // rotation manually.
+
+    if (!output.isHorizontal()) {
+        size = size.transposed();
+    }
+    return size;
+}
+
 QDebug operator<<(QDebug dbg, const KScreen::ConfigPtr &config)
 {
     if (config) {
