@@ -13,6 +13,7 @@
 #include "mode.h"
 
 #include <QCryptographicHash>
+#include <QGuiApplication>
 #include <QRect>
 #include <QScopedPointer>
 #include <QStringList>
@@ -28,7 +29,7 @@ public:
         , replicationSource(0)
         , rotation(None)
         , scale(1.0)
-        , logicalSize(QSizeF())
+        , explicitLogicalSize(QSizeF())
         , connected(false)
         , enabled(false)
         , primary(false)
@@ -51,6 +52,7 @@ public:
         , size(other.size)
         , rotation(other.rotation)
         , scale(other.scale)
+        , explicitLogicalSize(other.explicitLogicalSize)
         , connected(other.connected)
         , enabled(other.enabled)
         , primary(other.primary)
@@ -87,7 +89,7 @@ public:
     QSize size;
     Rotation rotation;
     qreal scale;
-    QSizeF logicalSize;
+    QSizeF explicitLogicalSize;
     bool connected;
     bool enabled;
     bool primary;
@@ -246,6 +248,43 @@ void Output::setType(Type type)
     Q_EMIT outputChanged();
 }
 
+QString Output::typeName() const
+{
+    switch (d->type) {
+    case Output::Unknown:
+        return QStringLiteral("Unknown");
+    case Output::Panel:
+        return QStringLiteral("Panel (Laptop)");
+    case Output::VGA:
+        return QStringLiteral("VGA");
+    case Output::DVI:
+        return QStringLiteral("DVI");
+    case Output::DVII:
+        return QStringLiteral("DVI-I");
+    case Output::DVIA:
+        return QStringLiteral("DVI-A");
+    case Output::DVID:
+        return QStringLiteral("DVI-D");
+    case Output::HDMI:
+        return QStringLiteral("HDMI");
+    case Output::TV:
+        return QStringLiteral("TV");
+    case Output::TVComposite:
+        return QStringLiteral("TV-Composite");
+    case Output::TVSVideo:
+        return QStringLiteral("TV-SVideo");
+    case Output::TVComponent:
+        return QStringLiteral("TV-Component");
+    case Output::TVSCART:
+        return QStringLiteral("TV-SCART");
+    case Output::TVC4:
+        return QStringLiteral("TV-C4");
+    case Output::DisplayPort:
+        return QStringLiteral("DisplayPort");
+    };
+    return QStringLiteral("Invalid Type") + QString::number(d->type);
+}
+
 QString Output::icon() const
 {
     return d->icon;
@@ -422,40 +461,18 @@ void Output::setScale(qreal factor)
     Q_EMIT scaleChanged();
 }
 
-QSizeF Output::logicalSize() const
-{
-    if (d->logicalSize.isValid()) {
-        return d->logicalSize;
-    }
-
-    QSizeF size = enforcedModeSize();
-    if (!size.isValid()) {
-        return QSizeF();
-    }
-    size = size / d->scale;
-
-    // We can't use d->size, because d->size does not reflect the actual rotation() set by caller.
-    // It is only updated when we get update from KScreen, but not when user changes mode or
-    // rotation manually.
-
-    if (!isHorizontal()) {
-        size = size.transposed();
-    }
-    return size;
-}
-
 QSizeF Output::explicitLogicalSize() const
 {
-    return d->logicalSize;
+    return d->explicitLogicalSize;
 }
 
-void Output::setLogicalSize(const QSizeF &size)
+void Output::setExplicitLogicalSize(const QSizeF &size)
 {
-    if (qFuzzyCompare(d->logicalSize.width(), size.width()) && qFuzzyCompare(d->logicalSize.height(), size.height())) {
+    if (qFuzzyCompare(d->explicitLogicalSize.width(), size.width()) && qFuzzyCompare(d->explicitLogicalSize.height(), size.height())) {
         return;
     }
-    d->logicalSize = size;
-    Q_EMIT logicalSizeChanged();
+    d->explicitLogicalSize = size;
+    Q_EMIT explicitLogicalSizeChanged();
 }
 
 bool Output::isConnected() const
@@ -591,7 +608,7 @@ QSize Output::enforcedModeSize() const
 
 QRect Output::geometry() const
 {
-    QSize size = logicalSize().toSize();
+    QSize size = explicitLogicalSize().toSize();
     if (!size.isValid()) {
         return QRect();
     }
