@@ -1,21 +1,9 @@
-/*************************************************************************************
- *  Copyright 2013 Alejandro Fiestas Olivares <afiestas@kde.org>                  *
- *  Copyright 2014 Sebastian Kügler <sebas@kde.org>                                  *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "testpnp.h"
 
@@ -116,7 +104,7 @@ void TestPnp::print()
     qDebug() << "\tcurrentSize:" << m_config->screen()->currentSize();
 
     const OutputList outputs = m_config->outputs();
-    Q_FOREACH (const OutputPtr &output, outputs) {
+    for (const OutputPtr &output : outputs) {
         qDebug() << "\n-----------------------------------------------------\n";
         qDebug() << "Id: " << output->id();
         qDebug() << "Name: " << output->name();
@@ -145,7 +133,7 @@ void TestPnp::print()
         qDebug() << "Modes: ";
 
         const ModeList modes = output->modes();
-        Q_FOREACH (const ModePtr &mode, modes) {
+        for (const ModePtr &mode : modes) {
             qDebug() << "\t" << mode->id() << "  " << mode->name() << " " << mode->size() << " " << mode->refreshRate();
         }
 
